@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: CaseClass.scala,v 1.13 2005/06/02 18:30:20 odersky Exp $
+** $Id: CaseClass.scala 5359 2005-12-16 15:33:49Z dubochet $
 \*                                                                      */
 
 package scala;
@@ -20,9 +20,14 @@ trait CaseClass extends AnyRef {
   */
   def caseElement(n: Int): Any ;
 
+  /** need also, for reflection
+  def setCaseElement(n: Int, v: Any): unit
+  */
+
   /** for a case class A(x_0,...,x_(k-1)), returns k
   */
   def caseArity: Int ;
 
   def caseName: String = ""; // for now
+
 }
