@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: Predef.scala,v 1.68 2005/11/07 14:20:49 mihaylov Exp $
+** $Id: Predef.scala 5359 2005-12-16 15:33:49Z dubochet $
 \*                                                                      */
 
 package scala;
@@ -144,6 +144,16 @@ object Predef {
       throw new Error("assertion failed: " + message);
   }
 
+  def assume(assumption: Boolean): Unit = {
+    if (!assumption)
+      throw new Error("assumption failed");
+  }
+
+  def assume(assumption: Boolean, message: Any): Unit = {
+    if (!assumption)
+      throw new Error("assumption failed: " + message);
+  }
+
   // views -------------------------------------------------------------
 
   implicit def identity[a](x: a): a = x;
