@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: HashMap.scala,v 1.7 2005/06/07 15:30:41 mihaylov Exp $
+** $Id: HashMap.scala 5359 2005-12-16 15:33:49Z dubochet $
 \*                                                                      */
 
 package scala.collection.mutable;
@@ -28,7 +28,7 @@ class HashMap[A, B] extends scala.collection.mutable.Map[A, B]
         tableSize = 0;
     }
 
-    override def clone(): HashMap[A, B] = {
+    override def clone(): Map[A, B] = {
         val res = new HashMap[A, B];
         res ++= this;
         res
