@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: LinkedList.scala,v 1.5 2005/06/07 15:30:41 mihaylov Exp $
+** $Id: LinkedList.scala 5359 2005-12-16 15:33:49Z dubochet $
 \*                                                                      */
 
 package scala.collection.mutable;
@@ -17,14 +17,18 @@ package scala.collection.mutable;
  */
 [serializable]
 class LinkedList[A](head: A, tail: LinkedList[A])
-  extends SingleLinkedList[A, LinkedList[A]]
+  extends SingleLinkedList[A, LinkedList[A]] 
 {
   elem = head;
   next = tail;
 
-  override def equals(obj: Any): Boolean =
+  override def equals(obj: Any): Boolean = (
     obj.isInstanceOf[LinkedList[A]]
-      && toList.equals((obj.asInstanceOf[LinkedList[A]]).toList);
+      && toList.equals((obj.asInstanceOf[LinkedList[A]]).toList)
+  );
 
   override protected def stringPrefix: String = "LinkedList";
 }
+
+
+
