@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: Stack.scala,v 1.16 2005/10/27 11:50:46 dragos Exp $
+** $Id: Stack.scala 5359 2005-12-16 15:33:49Z dubochet $
 \*                                                                      */
 
 package scala.collection.mutable;
@@ -99,12 +99,13 @@ class Stack[A] extends MutableList[A] {
      *  
      *  @return true, iff both stacks contain the same sequence of elements.
      */
-    override def equals(that: Any): Boolean =
+    override def equals(that: Any): Boolean = (
         that.isInstanceOf[Stack[A]] &&
         { val other = that.asInstanceOf[Stack[A]];
           elements.zip(other.elements).forall {
             case Pair(thiselem, thatelem) => thiselem == thatelem;
-        }};
+        }}
+    );
     
     /** The hashCode method always yields an error, since it is not
      *  safe to use mutable stacks as keys in hash tables.
