@@ -6,11 +6,24 @@
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: Actor.scala,v 1.9 2005/09/02 08:30:12 michelou Exp $
+// $Id: Actor.scala 5359 2005-12-16 15:33:49Z dubochet $
 
 package scala.concurrent;
 
+abstract class Actor extends Thread {
+  private val in = new MailBox;
+
+  def send(msg: in.Message) = 
+    in.send(msg);
+
+  def receive[a](f: PartialFunction[in.Message, a]): a = 
+    if (Thread.currentThread() == this) in.receive(f);
+    else error("receive called not on own process");
+
+  def receiveWithin[a](msec: long)(f: PartialFunction[in.Message, a]): a = 
+    if (Thread.currentThread() == this) in.receiveWithin(msec)(f);
+    else error("receiveWithin called not on own process");
+}
 
-abstract class Actor extends Thread with MailBox;
 
 
