@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: NameServer.scala,v 1.2 2004/02/16 12:50:17 michelou Exp $
+** $Id: NameServer.scala 5359 2005-12-16 15:33:49Z dubochet $
 \*                                                                      */
 
 package scala.concurrent;
@@ -29,7 +29,7 @@ object NameServer {
   def whereis(name: Symbol): Option[Process] = 
     names.get(name);
 
-  def send(name: Symbol, msg: Actor#Message) =
+  def send(name: Symbol, msg: MailBox#Message) =
     names(name).send(msg);
 
 }
