@@ -6,10 +6,11 @@
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: BoxedDoubleArray.scala,v 1.3 2005/08/26 12:25:43 michelou Exp $
+// $Id: BoxedDoubleArray.scala 5359 2005-12-16 15:33:49Z dubochet $
 
 package scala.runtime;
 
+[serializable]
 final class BoxedDoubleArray(val value: Array[Double]) extends BoxedArray {
 
   def length: Int = value.length;
@@ -22,9 +23,10 @@ final class BoxedDoubleArray(val value: Array[Double]) extends BoxedArray {
 
   def unbox(elemTag: String): Object = value;
 
-  override def equals(other: Any) =
+  override def equals(other: Any) = (
     value == other ||
-    other.isInstanceOf[BoxedDoubleArray] && value == other.asInstanceOf[BoxedDoubleArray].value;
+    other.isInstanceOf[BoxedDoubleArray] && value == other.asInstanceOf[BoxedDoubleArray].value
+  );
 
   override def hashCode(): Int = value.hashCode();
 }
