@@ -6,10 +6,11 @@
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: BoxedLongArray.scala,v 1.3 2005/08/26 12:25:58 michelou Exp $
+// $Id: BoxedLongArray.scala 5359 2005-12-16 15:33:49Z dubochet $
 
 package scala.runtime;
 
+[serializable]
 final class BoxedLongArray(val value: Array[Long]) extends BoxedArray {
 
   def length: Int = value.length;
@@ -22,9 +23,10 @@ final class BoxedLongArray(val value: Array[Long]) extends BoxedArray {
 
   def unbox(elemTag: String): Object = value;
 
-  override def equals(other: Any) =
+  override def equals(other: Any) = (
     value == other ||
-    other.isInstanceOf[BoxedLongArray] && value == other.asInstanceOf[BoxedLongArray].value;
+    other.isInstanceOf[BoxedLongArray] && value == other.asInstanceOf[BoxedLongArray].value
+  );
 
   override def hashCode(): Int = value.hashCode();
 }
