@@ -6,7 +6,7 @@
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: BoxedObjectArray.scala,v 1.3 2005/08/26 12:26:00 michelou Exp $
+// $Id: BoxedObjectArray.scala 5359 2005-12-16 15:33:49Z dubochet $
 
 package scala.runtime;
 
@@ -20,9 +20,10 @@ final class BoxedObjectArray(val value: Array[Object]) extends BoxedArray {
 
   def unbox(elemTag: String): Object = value;
 
-  override def equals(other: Any): Boolean =
+  override def equals(other: Any): Boolean = (
     value == other ||
-    other.isInstanceOf[BoxedObjectArray] && value == other.asInstanceOf[BoxedObjectArray].value;
+    other.isInstanceOf[BoxedObjectArray] && value == other.asInstanceOf[BoxedObjectArray].value
+  );
 
   override def hashCode(): Int = value.hashCode();
 }
