@@ -6,7 +6,7 @@
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: Elem.scala,v 1.20 2005/11/04 13:04:48 emir Exp $
+// $Id: Elem.scala 5359 2005-12-16 15:33:49Z dubochet $
 
 package scala.xml;
 
@@ -46,6 +46,9 @@ case class Elem(override val prefix: String,
 
   final override def typeTag$: Int = 0;
 
+  override def hashCode(): Int = {
+    Utility.hashCode(prefix, label, attributes.hashCode(), scope.hashCode(), child);
+  }
   /** Return a new element with updated attributes
    *
    *  @param attrs
@@ -63,7 +66,7 @@ case class Elem(override val prefix: String,
      val sb = new StringBuffer();
      val it = child.elements;
      while(it.hasNext) {
-       sb.append(it.next);
+       sb.append(it.next.text);
      }
      sb.toString()
    }
