@@ -6,7 +6,7 @@
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: Node.scala,v 1.36 2005/11/08 12:42:14 michelou Exp $
+// $Id: Node.scala 5359 2005-12-16 15:33:49Z dubochet $
 
 package scala.xml;
 
@@ -91,15 +91,15 @@ abstract class Node extends NodeSeq {
   /** structural equality */
   override def equals(x: Any): Boolean = x match {
     case that: Node => 
-      (that.prefix == this.prefix )
-      &&(that.label == this.label )
-      &&(that.attributes ==  this.attributes)
-      && that.child.sameElements(this.child) // sameElements
-      case _ => false
+      ((that.prefix == this.prefix )
+       &&(that.label == this.label )
+       &&(that.attributes ==  this.attributes)
+       && that.child.sameElements(this.child)) // sameElements
+    case _ => false
   }
   /** returns a hashcode */
   override def hashCode(): Int;
-    //Utility.hashCode(namespace, label, attributes.hashCode(), child);
+    //Utility.hashCode(pre, label, attributes.hashCode(), child);
 
 
   /** method for NodeSeq */
