@@ -6,7 +6,7 @@
 **                          |/                                          **
 \*                                                                      */
 
-// $Id: PrefixedAttribute.scala,v 1.4 2005/11/04 09:24:44 michelou Exp $
+// $Id: PrefixedAttribute.scala 5359 2005-12-16 15:33:49Z dubochet $
 
 package scala.xml;
 
@@ -17,6 +17,12 @@ class PrefixedAttribute(val pre: String,
                         val value: String,
                         val next: MetaData) extends MetaData {
 
+  // verify that value is a proper attribute value (references, no &lt;)
+  Utility.checkAttributeValue(value) match {
+    case null => ;
+    case msg  => throw new MalformedAttributeException(msg);
+  }
+
   /** Returns a copy of this unprefixed attribute with the given
    *  next field.
    */
@@ -38,9 +44,9 @@ class PrefixedAttribute(val pre: String,
   */
 
   def equals1(m: MetaData) =
-     m.isPrefixed &&
-     (m.asInstanceOf[PrefixedAttribute].pre == pre) &&
-     (m.key == key) && (m.value == value);
+     (m.isPrefixed &&
+      (m.asInstanceOf[PrefixedAttribute].pre == pre) &&
+      (m.key == key) && (m.value == value));
 
   def getNamespace(owner: Node) = 
     owner.getNamespace(pre);
