@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: ConstructingParser.scala,v 1.16 2005/06/09 12:27:47 buraq Exp $
+** $Id: ConstructingParser.scala 5359 2005-12-16 15:33:49Z dubochet $
 \*                                                                      */
 
 package scala.xml.parsing ;
@@ -26,7 +26,26 @@ object ConstructingParser {
   }
 }
 
-/** an xml parser. parses XML and invokes callback methods of a MarkupHandler
+/** an xml parser. parses XML and invokes callback methods of a MarkupHandler. Don't forget to call next.ch on a freshly
+ *  instantiated parser in order to initialize it. If you get the parser from the object method, initialization is already done for you.
+ *
+ *<pre>
+object parseFromURL {
+  def main(args:Array[String]): Unit = {
+    val url = args(0);
+    val src = scala.io.Source.fromURL(url);
+    val cpa = scala.xml.parsing.ConstructingParser.fromSource(src, false); // fromSource initializes automatically
+    val doc = cpa.document();
+
+    // let's see what it is
+    val ppr = new scala.xml.PrettyPrinter(80,5);
+    val ele = doc.docElem;
+    Console.println("finished parsing");
+    val out = ppr.format(ele);
+    Console.println(out);
+  }
+}
+</pre>
  */
 class ConstructingParser(inp: Source, presWS:Boolean) 
 extends  ConstructingHandler  
