@@ -4,7 +4,7 @@
 **  __\ \/ /__/ __ |/ /__/ __ |                                         **
 ** /____/\___/_/ |_/____/_/ | |                                         **
 **                          |/                                          **
-** $Id: MarkupParser.scala,v 1.42 2005/10/11 19:42:36 emir Exp $
+** $Id: MarkupParser.scala 5359 2005-12-16 15:33:49Z dubochet $
 \*                                                                      */
 
 package scala.xml.parsing;
@@ -82,11 +82,12 @@ import scala.xml.dtd._ ;
   }
 
   /** &lt;? prolog ::= xml S 
+   *  // this is a bit more lenient than necessary...
    */
   def prolog(): Tuple3[Option[String], Option[String], Option[Boolean]] = {
 
     //Console.println("(DEBUG) prolog");
-
+    var n = 0;
     var info_ver: Option[String] = None;
     var info_enc: Option[String] = None;
     var info_stdl: Option[Boolean] = None;
@@ -95,38 +96,32 @@ import scala.xml.dtd._ ;
 
     xSpace;    
 
-    if (!m.isPrefixed && m.key == "version") {
-      if (m.value == "1.0") {
-        info_ver = Some("1.0");
-        m = m.next;
-      } else {
-        reportSyntaxError("cannot deal with versions != 1.0");
-      }
-    } else
-      reportSyntaxError("VersionInfo expected!");
-    
-    if (!m.isPrefixed && m.key == "encoding") {
-      val enc = m.value;
-      if (!isValidIANAEncoding(enc))
-        reportSyntaxError("\"" + enc + "\" is not a valid encoding");
-      info_enc = Some(enc);
-      m = m.next
+    m.getValue("version") match {
+      case null  => ;
+      case "1.0" => info_ver = Some("1.0"); n = n + 1;
+      case _     => reportSyntaxError("cannot deal with versions != 1.0");
     }
-    
-    if (!m.isPrefixed && m.key == "standalone") {
-      m.value match {
-        case "yes" => 
-          info_stdl = Some(true);
-        case "no" =>
-          info_stdl = Some(false);
-        case _ => 
-          reportSyntaxError("either 'yes' or 'no' expected");
-      }
-      m = m.next
+
+    m.getValue("encoding") match {
+      case null => ;
+      case enc  => if (!isValidIANAEncoding(enc.toString()))
+                    reportSyntaxError("\"" + enc + "\" is not a valid encoding");
+                  else {
+                    info_enc = Some(enc.toString());
+                    n = n + 1;
+                  }
     }
-    
-    if (m != Null)
+    m.getValue("standalone") match {
+      case null => ;
+      case "yes" => info_stdl = Some(true);  n = n + 1;
+      case "no"  => info_stdl = Some(false); n = n + 1;
+      case _     => reportSyntaxError("either 'yes' or 'no' expected");
+    }
+
+    if(m.length - n != 0) {
       reportSyntaxError("VersionInfo EncodingDecl? SDDecl? or '?>' expected!");
+    }
+    //Console.println("[MarkupParser::prolog] finished parsing prolog!");
     Tuple3(info_ver,info_enc,info_stdl)
   }
 
@@ -137,28 +132,28 @@ import scala.xml.dtd._ ;
     var info_enc: Option[String] = None;
 
     var m = xmlProcInstr();
+    var n = 0;
 
-    if (!m.isPrefixed && m.key == "version") {
-      if (m.value == "1.0") {
-        info_ver = Some("1.0");
-        m = m.next;
-      } else {
-        reportSyntaxError("cannot deal with versions != 1.0");
-      }
-    } else
-      reportSyntaxError("VersionInfo expected!");
-    
-    if (m != Null && !m.isPrefixed && m.key == "encoding") {
-      val enc = m.value;
-      if (!isValidIANAEncoding(enc))
-        reportSyntaxError("\"" + enc + "\" is not a valid encoding");
-      info_enc = Some(enc);
-      m = m.next
+    m.getValue("version") match {
+      case null => ;
+      case "1.0" => info_ver = Some("1.0"); n = n + 1;
+      case _     => reportSyntaxError("cannot deal with versions != 1.0");
     }
 
-    if (m != Null)
-      reportSyntaxError("VersionInfo EncodingDecl? SDDecl? or '?>' expected!");
+    m.getValue("encoding") match {
+      case null => ;
+      case enc  => if (!isValidIANAEncoding(enc.toString()))
+        reportSyntaxError("\"" + enc + "\" is not a valid encoding");
+                   else {
+                     info_enc = Some(enc.toString());
+                     n = n + 1;
+                   }
+    }
 
+    if(m.length - n != 0) {
+      reportSyntaxError("VersionInfo EncodingDecl? or '?>' expected!");
+    }
+    //Console.println("[MarkupParser::textDecl] finished parsing textdecl");
     Tuple2(info_ver, info_enc);
   }
 
@@ -184,11 +179,21 @@ import scala.xml.dtd._ ;
     }
 
     nextch; // is prolog ?
+    var children: NodeSeq = null;
     if ('?' == ch) {
+      //Console.println("[MarkupParser::document] starts with xml declaration");
       nextch;
       info_prolog = prolog();
+      children = content(TopScope); // DTD handled as side effect
+      
+    } else {
+      //Console.println("[MarkupParser::document] does not start with xml declaration");
+      val ts = new NodeBuffer();
+      content1(TopScope, ts); // DTD handled as side effect
+      ts &+ content(TopScope);
+      children = NodeSeq.fromSeq(ts);
     }
-    val children = content(TopScope); // DTD handled as side effect
+    //Console.println("[MarkupParser::document] children now: "+children.toList);
     var elemCount = 0;
     var theNode: Node = null;
     for (val c <- children) c match {
@@ -326,9 +331,8 @@ import scala.xml.dtd._ ;
     val str = cbuf.toString();
     cbuf.setLength(0);
 
-    // @todo: normalize attribute value
     // well-formedness constraint
-    str
+    normalizeAttributeValue(str)
     
   }
 
@@ -404,25 +408,25 @@ import scala.xml.dtd._ ;
    *
    * see [66]
    */
-  def xCharRef: String = {
-    val hex  = (ch == 'x') && { nextch; true };
+  def xCharRef(ch: () => Char, nextch: () => Unit): String = {
+    val hex  = (ch() == 'x') && { nextch(); true };
     val base = if (hex) 16 else 10;
     var i = 0;
-    while (ch != ';') {
-      ch match {
+    while (ch() != ';') {
+      ch() match {
         case '0' | '1' | '2' | '3' | '4' | '5' | '6' | '7' | '8' | '9' =>
-          i = i * base + Character.digit( ch, base );
+          i = i * base + Character.digit( ch(), base );
         case 'a' | 'b' | 'c' | 'd' | 'e' | 'f'
            | 'A' | 'B' | 'C' | 'D' | 'E' | 'F' =>
           if (! hex) 
             reportSyntaxError("hex char not allowed in decimal char ref\n"
                          +"Did you mean to write &#x ?");
           else 
-            i = i * base + Character.digit(ch, base);
+            i = i * base + Character.digit(ch(), base);
         case _ =>
-          reportSyntaxError("character '" + ch + " not allowed in char ref\n");
+          reportSyntaxError("character '" + ch() + " not allowed in char ref\n");
       }
-      nextch;
+      nextch();
     }
     new String(Predef.Array(i.asInstanceOf[char]))
   }
@@ -513,16 +517,24 @@ import scala.xml.dtd._ ;
             ch match {
               case '#' => // CharacterRef
                 nextch;
-              val theChar = handle.text( tmppos, xCharRef );
-              xToken(';');
-              ts &+ theChar ;
+                val theChar = handle.text( tmppos, 
+                                          xCharRef ({ ()=> ch },{ () => nextch }) );
+                xToken(';');
+                ts &+ theChar ;
               case _ => // EntityRef
                 val n = xName ;
                 xToken(';');
-                /*
-                ts + handle.entityRef( tmppos, n ) ;
-                */
-                push( n );
+                n match {
+                  case "lt"    => ts &+ '<';
+                  case "gt"    => ts &+ '>';
+                  case "amp"   => ts &+ '&';
+                  case "quote" => ts &+ '"';
+                  case _ =>
+                    /*
+                     ts + handle.entityRef( tmppos, n ) ;
+                     */
+                    push( n );
+                }
             }
           case _ => // text content
             //Console.println("text content?? pos = "+pos);
@@ -576,13 +588,13 @@ import scala.xml.dtd._ ;
     //external ID
     if('S' == ch || 'P' == ch) { 
       extID = externalID();
-      xSpace;
+      xSpaceOpt;
     }
 
     /* parse external subset of DTD 
      */
     
-    if(null != extID) {
+    if((null != extID)&&(isValidating)) {
 
       pushExternal(extID.systemId);
       //val extSubsetSrc = externalSource( extID.systemId );
@@ -689,8 +701,7 @@ import scala.xml.dtd._ ;
       val n = cbuf.toString().intern();
       cbuf.setLength(0);
       n
-    }
-    else {
+    } else {
       reportSyntaxError("name expected");
       new String()
     }
@@ -1108,7 +1119,8 @@ import scala.xml.dtd._ ;
    * report a syntax error
    */
   def reportSyntaxError(pos: int, str: String): Unit = {
-    curInput.reportError(pos, str)
+    curInput.reportError(pos, str);
+    //error("MarkupParser::synerr"); // DEBUG
   }
 
   def reportSyntaxError(str: String): Unit = reportSyntaxError(pos, str);
@@ -1165,4 +1177,47 @@ import scala.xml.dtd._ ;
     //Console.println(inpStack.map { x => x.descr });
   }
 
+  /** for the moment, replace only character references 
+   *  see spec 3.3.3
+   *  precond: cbuf empty
+   */
+  def normalizeAttributeValue(attval: String) = {
+    val s:Seq[Char] = attval;
+    val it = s.elements;
+    while(it.hasNext) {
+      it.next match {
+        case ' '|'\t'|'\n'|'\r' => 
+          cbuf.append(' ');
+        case '&' => it.next match {
+          case '#' =>
+            var c = it.next;
+            val s = xCharRef ({ () => c }, { () => c = it.next });
+            cbuf.append(s);
+          case nchar => 
+            val nbuf = new StringBuffer();
+            var d = nchar;
+            do { 
+              nbuf.append(d); 
+              d = it.next; 
+            } while(d != ';');
+            nbuf.toString() match {
+              case "lt"    => cbuf.append('<');
+              case "gt"    => cbuf.append('>');
+              case "amp"   => cbuf.append('&');
+              case "quote" => cbuf.append('"');
+              case name =>
+                //don't handle entityrefs for now
+                cbuf.append('&');
+                cbuf.append(name);
+                cbuf.append(';');
+            }
+        }
+        case c => cbuf.append(c);
+      }
+    }
+    val name = cbuf.toString();
+    cbuf.setLength(0);
+    name
+  }
+
 }
