@@ -1,5 +1,5 @@
 ;;; scala.el - Major mode for editing Scala code.
-;;; $Id: scala-mode.el,v 1.15 2005/10/17 16:03:34 dragos Exp $
+;;; $Id: scala-mode.el 5359 2005-12-16 15:33:49Z dubochet $
 
 ;;; TODO
 ;;; - make automatic indentation work in all cases
@@ -9,7 +9,7 @@
 (require 'cl)
 (require 'regexp-opt)
 
-(defconst scala-mode-version "0.3 ($Revision: 1.15 $)")
+(defconst scala-mode-version "0.3 ($Revision: 5359 $)")
 (defconst scala-bug-e-mail "Michel.Schinz@epfl.ch")
 (defconst scala-web-url "http://scala.epfl.ch/")
 
@@ -119,9 +119,9 @@ reserved keywords when used alone.")
 (defconst scala-keywords-re
   (regexp-opt '("abstract" "case" "class" "catch" "def" "do" "else" "extends"
                 "final" "finally" "for" "if" "implicit" "import" "new" "match"
-                "object" "override" "package" "private" "protected" "return"
-                "sealed" "super" "this" "throw" "trait" "try" "type" "val"
-                "var" "with" "while" "yield")
+                "object" "override" "package" "private" "protected" "requires"
+                "return" "sealed" "super" "this" "throw" "trait" "try" "type"
+                "val" "var" "with" "while" "yield")
 	      'words))
 
 (defconst scala-constants-re
