@@ -4,6 +4,20 @@ import scala.testing.UnitTest._ ;
 import scala.xml.{Node, NodeSeq, Elem, Text, XML};
 
 object Test {
+
+  /** returns true if exception was thrown */
+  def catcher(att:Function1[Unit,scala.xml.MetaData]): Boolean = {
+    var ex = false;
+      try {
+        val x = att.apply({});
+      } catch {
+        case scala.xml.MalformedAttributeException(msg) =>
+          Console.println(msg);
+          ex = true;
+      }
+    return ex;
+  }
+
   def main(args:Array[String]) = {
 
   //val e:  scala.xml.MetaData         = null; //Node.NoAttributes;
@@ -11,6 +25,32 @@ object Test {
 
     // ------------------------------------------ tests for class NodeSeq
 
+    /**
+    Console.println("checking wellformed attributes");
+    {
+    import scala.xml.{ UnprefixedAttribute, Null }
+    assertTrue(catcher {x:Unit => new UnprefixedAttribute("key", "<", Null)});   // < illegal
+    assertTrue(catcher(x:Unit => new UnprefixedAttribute("key", "&", Null)));   // & illegal
+    assertTrue(catcher(x:Unit => new UnprefixedAttribute("key", "a&a", Null))); // & illegal
+    assertTrue(catcher(x:Unit => new UnprefixedAttribute("key", "a&a;&", Null))); // 2nd &
+
+    assertFalse(catcher(x:Unit => new UnprefixedAttribute("key", "a&a; &lt;&lt;", Null)));
+    }
+*/
+
+/*
+checking wellformed attributes
+< not allowed in attribute value
+passed ok
+malformed entity reference in attribute value [&]
+passed ok
+malformed entity reference in attribute value [a&a]
+passed ok
+malformed entity reference in attribute value [a&a;&]
+passed ok
+passed ok
+*/
+
   Console.println("NodeSeq");
   import scala.xml.Utility.view ;
 
@@ -21,7 +61,7 @@ object Test {
             </foo>;
   
     val pelems_1 = for( val x <- p \ "bar"; val y <- p \ "baz" ) yield {
-      Text(x.attribute("value") + y.attribute("bazValue")+ "!")
+      Text(x.attribute("value").toString() + y.attribute("bazValue").toString()+ "!")
     };
     val pelems_2 = new NodeSeq { val theSeq = List(Text("38!"),Text("58!")) };
     assertSameElements(pelems_1, pelems_2);
@@ -29,6 +69,28 @@ object Test {
       p \\ "@value", new NodeSeq { val theSeq = List(Text("3"), Text("5")) }
     );
 
+
+    /* // more test cases !!!
+    val test = <a name="bar"/>;
+    
+    Console.println(test \ "@name");
+    
+    val x = test.attributes.nodes;
+    Console.println("trying to print");
+    val it = x.elements;
+    while(it.hasNext) {
+      val c = it.next;
+      Console.println(c);
+      Console.println("c.label == @name? "+(c.label == "@name"));
+    }
+    */
+
+    /*
+    for(val c <- x) {
+      Console.println(x);
+    }
+    */
+
     val books = 
     <bks>
       <book><title>Blabla</title></book>
@@ -115,9 +177,9 @@ val addrBook =
   assertEquals(
      <hello foo="bar">
        <world/>
-     </hello> match { case <hello>
+     </hello> match { case x @ <hello>
                                <world/>
-                           </hello> => true; 
+                           </hello> if x.attribute("foo") == "bar" => true; 
                       case _ => false; },
                true);
 
